==> SyL-0.9.0.tar.gz: SyL/include/framework/Controller/SyL_ControllerJs.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerJs.php,v 1.1 2007/03/17 13:53:08 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ǡ饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';

/**
 * Ajaxȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream       - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   executeStream  - ¹
 *   3.   renderStream   - ӥ塼ɽ¹
 *   4. finalStream      - shutdown
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerJs.php,v 1.1 2007/03/17 13:53:08 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerJs extends SyL_Controller
{
    /**
     * ե륿ե̾
     *
     * @access private
     * @var string
     */
    var $action_file_name = 'actions.xml';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param array Ķ
     */
    function SyL_ControllerJs($config)
    {
        // 󥭡
        if (isset($config['action_key']) && $config['action_key']) {
            define('SYL_ACTION_KEY', $config['action_key']);
        } else {
            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
        }

        // ƤΥ󥹥ȥ饯
        parent::SyL_Controller($config);
    }

    /**
     * 
     *
     * @access protected
     */
    function initStream()
    {
        // Х륳ݡͥե
        $config_file = array();
        $config_file['components'] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
        // ٥ȼ¹
        $this->raiseEvent('initStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function loadStream()
    {
        // Хե륿ե
        $global_filters_file = SYL_WEBAPP_CONFIG_DIR . "/{$this->filter_file_name}";
        // ץꥱե륿ե
        $app_filters_file = SYL_APP_DIR . "/{$this->filter_file_name}";

        $config_file = array();
        $config_file['filters'] = $app_filters_file . PATH_SEPARATOR . $global_filters_file;

        // ٥ȼ¹
        $this->raiseEvent('loadStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function executeStream()
    {
        // ¹Ƚ
        $config_file = array();
        // ե
        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";

        // ٥ȼ¹
        $this->raiseEvent('executeStream', $config_file);
    }

    /**
     * ȥݥ
     *
     * @access public
     */
    function stream()
    {
        // 
        $this->initStream();
        // ¹
        $this->loadStream();
        // ¹Խ
        $this->executeStream();
        // ӥ塼ɽ¹
        $this->middleStream();
        // ӥ塼ɽ¹
        $this->renderStream();
        // ӥ塼ɽ¹Ը
        $this->unloadStream();
/*
echo "<pre>";
print_r($this->container->components);
echo "</pre>";

*/
    }
}

?>

==> SyL-0.10.0.tar.gz: SyL/include/framework/Controller/SyL_ControllerJs.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerJs.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * JavaScriptϥȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream         - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   loadStream       - ¹
 *   3.     executeStream  - ¹
 *   4.       middleStream - ¹Ը塢ӥ塼ɽ¹
 *   5.     renderStream   - ӥ塼ɽ¹
 *   6.   unloadStream     - ӥ塼ɽ¹Ը
 *   7. finalStream        - shutdown
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerJs.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerJs extends SyL_Controller
{
    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param array Ķ
     */
    function SyL_ControllerJs($config)
    {
        // 󥭡
        if (isset($config['action_key']) && $config['action_key']) {
            define('SYL_ACTION_KEY', $config['action_key']);
        } else {
            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
        }

        // ƤΥ󥹥ȥ饯
        parent::SyL_Controller($config);
    }

    /**
     * 
     *
     * @access protected
     */
    function initStream()
    {
        // Х륳ݡͥե
        $config_file = array();
        $config_file['components'] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
        // ٥ȼ¹
        $this->raiseEvent('initStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function loadStream()
    {
        // Хե륿ե
        $global_filters_file = SYL_WEBAPP_CONFIG_DIR . "/{$this->filter_file_name}";
        // ץꥱե륿ե
        $app_filters_file = SYL_APP_DIR . "/{$this->filter_file_name}";

        $config_file = array();
        $config_file['filters'] = $app_filters_file . PATH_SEPARATOR . $global_filters_file;

        // ٥ȼ¹
        $this->raiseEvent('loadStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function executeStream()
    {
        // ¹Ƚ
        $config_file = array();
        // ե
        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";

        // ٥ȼ¹
        $this->raiseEvent('executeStream', $config_file);
    }

    /**
     * ȥݥ
     *
     * @access public
     */
    function stream()
    {
        // 
        $this->initStream();
        // ¹
        $this->loadStream();
        // ¹Խ
        $this->executeStream();
        // ӥ塼ɽ¹
        $this->middleStream();
        // ӥ塼ɽ¹
        $this->renderStream();
        // ӥ塼ɽ¹Ը
        $this->unloadStream();
/*
echo "<pre>";
print_r($this->container->components);
echo "</pre>";

*/
    }
}

?>
